==> material-react-table-2.0.1.tgz: package/locales/zh-Hans/index.esm.js <==
const MRT_Localization_ZH_HANS = {
    actions: '操作',
    and: '与',
    cancel: '取消',
    changeFilterMode: '更改过滤模式',
    changeSearchMode: '更改搜索模式',
    clearFilter: '清除过滤',
    clearSearch: '清除搜索',
    clearSort: '清除排序',
    clickToCopy: '点击以复制',
    collapse: '折叠',
    collapseAll: '全部折叠',
    columnActions: '列操作',
    copiedToClipboard: '已复制至剪贴板',
    dropToGroupBy: '拖放以按 {column} 分组',
    edit: '编辑',
    expand: '展开',
    expandAll: '全部展开',
    filterArrIncludes: '包括',
    filterArrIncludesAll: '包括所有',
    filterArrIncludesSome: '包括',
    filterBetween: '介于首尾',
    filterBetweenInclusive: '介于首尾之间',
    filterByColumn: '以 {column} 过滤',
    filterContains: '包含',
    filterEmpty: '是空字串',
    filterEndsWith: '结尾为',
    filterEquals: '等于',
    filterEqualsString: '等于',
    filterFuzzy: '模糊搜索',
    filterGreaterThan: '大于',
    filterGreaterThanOrEqualTo: '大于等于',
    filterInNumberRange: '介于',
    filterIncludesString: '包含',
    filterIncludesStringSensitive: '包含',
    filterLessThan: '小于',
    filterLessThanOrEqualTo: '小于等于',
    filterMode: '过滤模式：{filterType}',
    filterNotEmpty: '非空字串',
    filterNotEquals: '不等于',
    filterStartsWith: '开首为',
    filterWeakEquals: '等于',
    filteringByColumn: '以 {column} 过滤：{filterType} {filterValue}',
    goToFirstPage: '到第一页',
    goToLastPage: '到最后一页',
    goToNextPage: '下一页',
    goToPreviousPage: '上一页',
    grab: '拖曳',
    groupByColumn: '按 {column} 分组',
    groupedBy: '分组依据 ',
    hideAll: '隐藏全部',
    hideColumn: '隐藏 {column} 列',
    max: '最大',
    min: '最小',
    move: '移动',
    noRecordsToDisplay: '无记录可显示',
    noResultsFound: '未找到结果',
    of: '/',
    or: '或',
    pin: '固定',
    pinToLeft: '固定至左边',
    pinToRight: '固定至右边',
    resetColumnSize: '重置列大小',
    resetOrder: '重置排序',
    rowActions: '行操作',
    rowNumber: '#',
    rowNumbers: '行号码',
    rowsPerPage: '每页行数',
    save: '保存',
    search: '搜索',
    selectedCountOfRowCountRowsSelected: '已选择行：{selectedCount}/{rowCount}',
    select: '选择',
    showAll: '显示全部',
    showAllColumns: '显示全部列',
    showHideColumns: '显示/隐藏 列',
    showHideFilters: '显示/隐藏 过滤条件',
    showHideSearch: '显示/隐藏 搜索条件',
    sortByColumnAsc: '按 {column} 顺序排序',
    sortByColumnDesc: '按 {column} 倒序排序',
    sortedByColumnAsc: '已按 {column} 顺序排序',
    sortedByColumnDesc: '已按 {column} 倒序排序',
    thenBy: '，然后以',
    toggleDensity: '切换间距',
    toggleFullScreen: '切换全屏',
    toggleSelectAll: '切换选择全部',
    toggleSelectRow: '切换选择行',
    toggleVisibility: '切换可见度',
    ungroupByColumn: '取消按 {column} 分组',
    unpin: '取消固定',
    unpinAll: '全部取消固定',
};

export { MRT_Localization_ZH_HANS };

==> material-react-table-2.0.4.tgz: package/locales/zh-Hans/index.esm.js <==
const MRT_Localization_ZH_HANS = {
    actions: '操作',
    and: '与',
    cancel: '取消',
    changeFilterMode: '更改过滤模式',
    changeSearchMode: '更改搜索模式',
    clearFilter: '清除过滤',
    clearSearch: '清除搜索',
    clearSort: '清除排序',
    clickToCopy: '点击以复制',
    collapse: '折叠',
    collapseAll: '全部折叠',
    columnActions: '列操作',
    copiedToClipboard: '已复制至剪贴板',
    dropToGroupBy: '拖放以按 {column} 分组',
    edit: '编辑',
    expand: '展开',
    expandAll: '全部展开',
    filterArrIncludes: '包括',
    filterArrIncludesAll: '包括所有',
    filterArrIncludesSome: '包括',
    filterBetween: '介于首尾',
    filterBetweenInclusive: '介于首尾之间',
    filterByColumn: '以 {column} 过滤',
    filterContains: '包含',
    filterEmpty: '是空字串',
    filterEndsWith: '结尾为',
    filterEquals: '等于',
    filterEqualsString: '等于',
    filterFuzzy: '模糊搜索',
    filterGreaterThan: '大于',
    filterGreaterThanOrEqualTo: '大于等于',
    filterInNumberRange: '介于',
    filterIncludesString: '包含',
    filterIncludesStringSensitive: '包含',
    filterLessThan: '小于',
    filterLessThanOrEqualTo: '小于等于',
    filterMode: '过滤模式：{filterType}',
    filterNotEmpty: '非空字串',
    filterNotEquals: '不等于',
    filterStartsWith: '开首为',
    filterWeakEquals: '等于',
    filteringByColumn: '以 {column} 过滤：{filterType} {filterValue}',
    goToFirstPage: '到第一页',
    goToLastPage: '到最后一页',
    goToNextPage: '下一页',
    goToPreviousPage: '上一页',
    grab: '拖曳',
    groupByColumn: '按 {column} 分组',
    groupedBy: '分组依据 ',
    hideAll: '隐藏全部',
    hideColumn: '隐藏 {column} 列',
    max: '最大',
    min: '最小',
    move: '移动',
    noRecordsToDisplay: '无记录可显示',
    noResultsFound: '未找到结果',
    of: '/',
    or: '或',
    pin: '固定',
    pinToLeft: '固定至左边',
    pinToRight: '固定至右边',
    resetColumnSize: '重置列大小',
    resetOrder: '重置排序',
    rowActions: '行操作',
    rowNumber: '#',
    rowNumbers: '行号码',
    rowsPerPage: '每页行数',
    save: '保存',
    search: '搜索',
    selectedCountOfRowCountRowsSelected: '已选择行：{selectedCount}/{rowCount}',
    select: '选择',
    showAll: '显示全部',
    showAllColumns: '显示全部列',
    showHideColumns: '显示/隐藏 列',
    showHideFilters: '显示/隐藏 过滤条件',
    showHideSearch: '显示/隐藏 搜索条件',
    sortByColumnAsc: '按 {column} 升序排序',
    sortByColumnDesc: '按 {column} 倒序排序',
    sortedByColumnAsc: '已按 {column} 升序排序',
    sortedByColumnDesc: '已按 {column} 倒序排序',
    thenBy: '，然后以',
    toggleDensity: '切换间距',
    toggleFullScreen: '切换全屏',
    toggleSelectAll: '切换选择全部',
    toggleSelectRow: '切换选择行',
    toggleVisibility: '切换可见度',
    ungroupByColumn: '取消按 {column} 分组',
    unpin: '取消固定',
    unpinAll: '全部取消固定',
};

export { MRT_Localization_ZH_HANS };
